/*
 * Copyright (C) 2010 Ixonos Plc.
 * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
 *
 * This file is part of ConfClerk.
 *
 * ConfClerk is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 2 of the License, or (at your option)
 * any later version.
 *
 * ConfClerk is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * ConfClerk.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONFLICTDIALOGCONTAINER_H
#define CONFLICTDIALOGCONTAINER_H

#include "tabcontainer.h"

class ConflictDialogContainer: public TabContainer
{
    Q_OBJECT
public:
    ConflictDialogContainer(QWidget *aParent);
    virtual ~ConflictDialogContainer() {}

public slots:
    void setEventId(int aEventId, int conferenceId);
    void loadEvents(); // update the conflicts

protected:
    virtual void loadEvents(const QDate &aDate, const int aConferenceId); // the date and conference are ignored

private:
    int mEventId;
    int mConferenceId;
};

#endif /* CONFLICTDIALOGCONTAINER_H */

